@@ -50,7 +50,7 @@ asvar.response <- function(object, name, prob = c(.1, .9), support = NULL, bound
 }
 
 mkbasis <- function(yvar, transformation = c("discrete", "linear", "logarithmic", "smooth"), 
-                    order = 6, extrapolate = FALSE) {
+                    order = 6, extrapolate = FALSE, log_first = FALSE) {
 
   transformation <- match.arg(transformation)
 
@@ -64,7 +64,7 @@ mkbasis <- function(yvar, transformation = c("discrete", "linear", "logarithmic"
               log_basis(yvar, ui = "increasing"),
           "smooth" = 
               Bernstein_basis(yvar, ui = "increasing", order = order,
-                              extrapolate = extrapolate)
+                              extrapolate = extrapolate, log_first = log_first)
           )
       )
   }
